staging:iio:buffering cleanup ring_buffer_register_ex naming.

Now the old method is long gone, lets get rid of the _ex and whilst
here remove the unused id parameter.

Trivial mechanical change, but will break any out of tree drivers
using this.

V2: rebase
V3: rebase

Signed-off-by: Jonathan Cameron <jic23@cam.ac.uk>
Signed-off-by: Greg Kroah-Hartman <gregkh@suse.de>
diff --git a/drivers/staging/iio/ring_generic.h b/drivers/staging/iio/ring_generic.h
index 37ab4db..25aacf3 100644
--- a/drivers/staging/iio/ring_generic.h
+++ b/drivers/staging/iio/ring_generic.h
@@ -206,13 +206,12 @@
 	container_of(d, struct iio_ring_buffer, dev)
 
 /**
  * iio_ring_buffer_register_ex() - register the buffer with IIO core
  * @indio_dev: device with the buffer to be registered
- * @id: the id of the buffer (typically 0)
  **/
-int iio_ring_buffer_register_ex(struct iio_dev *indio_dev, int id,
-				const struct iio_chan_spec *channels,
-				int num_channels);
+int iio_ring_buffer_register(struct iio_dev *indio_dev,
+			     const struct iio_chan_spec *channels,
+			     int num_channels);
 
 /**
  * iio_ring_buffer_unregister() - unregister the buffer from IIO core
@@ -265,10 +264,9 @@
 
 #else /* CONFIG_IIO_RING_BUFFER */
 
-static inline int iio_ring_buffer_register_ex(struct iio_dev *indio_dev,
-					      int id,
-					      struct iio_chan_spec *channels,
-					      int num_channels)
+static inline int iio_ring_buffer_register(struct iio_dev *indio_dev,
+					   struct iio_chan_spec *channels,
+					   int num_channels)
 {
 	return 0;
 }
@@ -206,13 +206,12 @@
 
 /**
- * iio_ring_buffer_register_ex() - register the buffer with IIO core
+ * iio_ring_buffer_register() - register the buffer with IIO core
  * @indio_dev: device with the buffer to be registered